/*
 * Fabric3
 * Copyright (c) 2009 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------
 *
 * Portions originally based on Apache Tuscany 2007
 * licensed under the Apache 2.0 license.
 *
 */
package org.fabric3.runtime.webapp;

import java.io.File;
import java.net.URI;
import javax.servlet.ServletContext;

import org.fabric3.host.RuntimeMode;

/**
 * @version $Rev: 9054 $ $Date: 2010-05-27 17:31:24 +0000 (Thu, 27 May 2010) $
 */
public class WebappHostInfoImpl implements WebappHostInfo {
    private final ServletContext servletContext;
    private final URI domain;
    private final File baseDir;
    private final File tempDirectory;

    public WebappHostInfoImpl(ServletContext servletContext, URI domain, File baseDir, File tempDirectory) {
        this.servletContext = servletContext;
        this.domain = domain;
        this.baseDir = baseDir;
        this.tempDirectory = tempDirectory;
    }

    public String getRuntimeId() {
        return "webapp";
    }

    public ServletContext getServletContext() {
        return servletContext;
    }

    public File getBaseDir() {
        return baseDir;
    }

    public File getTempDir() {
        return tempDirectory;
    }

    public File getDataDir() {
        // use the temp directory
        return tempDirectory;
    }

    public File getInstallDirectory() {
        throw new UnsupportedOperationException();
    }

    public File getConfigDirectory() {
        return null;
    }

    public File getUserRepositoryDirectory() {
        return baseDir;
    }

    public File getRuntimeRepositoryDirectory() {
        return null;
    }

    public File getExtensionsRepositoryDirectory() {
        return null;
    }

    public File getDeployDirectory() {
        return null;
    }

    public RuntimeMode getRuntimeMode() {
        return RuntimeMode.VM;
    }

    public URI getDomain() {
        return domain;
    }

    public boolean supportsClassLoaderIsolation() {
        return false;
    }
}
